v0.0.8
------

- exchange cleanup
- drop len
- add locks stores
- decover
- extend simplified functions
- fancify
- cover and raise
- minimal lock test
- init in test
- update path calculation
- bump v
